Metrics
========

Concept-aware metrics with automatic routing and flexible tracking.

.. currentmodule:: torch_concepts.nn.modules.metrics

Summary
-------

**Metrics Classes**

.. autosummary::
   :toctree: generated
   :nosignatures:

   ConceptMetrics

**Functional Metrics**

.. autosummary::
   :toctree: generated
   :nosignatures:

   completeness_score
   intervention_score
   cace_score


Class Documentation
-------------------

.. autoclass:: ConceptMetrics
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members: __init__, __repr__


Functional Metrics
------------------

.. currentmodule:: torch_concepts.nn.functional

.. autosummary::
   :toctree: generated
   :nosignatures:

   completeness_score
   intervention_score
   cace_score

.. autofunction:: completeness_score
.. autofunction:: intervention_score
.. autofunction:: cace_score

